# Main Package API

The main `openaivec` package provides the core classes for AI-powered data processing.

## Core Classes

All core functionality is accessible through the main package imports:

::: openaivec.BatchResponses

::: openaivec.AsyncBatchResponses

::: openaivec.BatchEmbeddings

::: openaivec.AsyncBatchEmbeddings

## Prompt Building

::: openaivec.FewShotPromptBuilder
